==> eiffelstudio-16.05.tar: F_code/C1/fi35.c <==
/*
 * Code for class FILE_UTILITIES
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "fi35.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {FILE_UTILITIES}.directory_exists */
EIF_BOOLEAN F56_744 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,arg1);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	Result = '\0';
	tb1 = (FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE)) R4839[Dtype(arg1)-890])(RTCW(arg1));
	if ((EIF_BOOLEAN) !tb1) {
		tr1 = RTLNS(eif_new_type(456, 0x00).id, 456, _OBJSIZ_3_0_0_1_0_2_0_0_);
		F457_3658(RTCW(tr1), arg1);
		tb1 = F457_3683(RTCW(tr1));
		Result = tb1;
	}
	RTLE;
	return Result;
}

/* {FILE_UTILITIES}.file_names */
#undef EIF_VOLATILE
#define EIF_VOLATILE volatile
EIF_REFERENCE F56_745 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	RTED;
	EIF_REFERENCE EIF_VOLATILE loc1 = (EIF_REFERENCE) 0;
	EIF_BOOLEAN EIF_VOLATILE loc2 = (EIF_BOOLEAN) 0;
	EIF_REFERENCE EIF_VOLATILE loc3 = (EIF_REFERENCE) 0;
	EIF_REFERENCE EIF_VOLATILE loc4 = (EIF_REFERENCE) 0;
	EIF_REFERENCE EIF_VOLATILE saved_except = (EIF_REFERENCE) 0;
	EIF_REFERENCE  EIF_VOLATILE tr1 = NULL;
	EIF_REFERENCE  EIF_VOLATILE tr2 = NULL;
	EIF_BOOLEAN  EIF_VOLATILE tb1;
	EIF_BOOLEAN  EIF_VOLATILE tb2;
	EIF_BOOLEAN  EIF_VOLATILE tb3;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	RTXD;
	
	RTLI(9);
	RTLR(0,loc1);
	RTLR(1,tr1);
	RTLR(2,arg1);
	RTLR(3,loc3);
	RTLR(4,tr2);
	RTLR(5,Current);
	RTLR(6,Result);
	RTLR(7,loc4);
	RTLR(8,saved_except);
	RTLIU(9);
	RTXSLS;
	
	RTEV;
	RTGC;
	RTE_T
	if ((EIF_BOOLEAN) !loc2) {
		tr1 = RTLNS(eif_new_type(456, 0x00).id, 456, _OBJSIZ_3_0_0_1_0_2_0_0_);
		F457_3658(RTCW(tr1), arg1);
		loc1 = (EIF_REFERENCE) tr1;
		tb1 = '\0';
		tb2 = F457_3683(RTCW(loc1));
		if (tb2) {
			tb2 = F457_3684(RTCW(loc1));
			tb1 = tb2;
		}
		if (tb1) {
			F457_3668(RTCW(loc1));
			tr1 = RTLNS(eif_new_type(729, 0x00).id, 729, _OBJSIZ_4_6_2_4_1_1_2_1_);
			tr2 = RTMS32_EX_H(".\000\000\000",1,46);
			F729_4715(RTCW(tr1), tr2);
			loc3 = (EIF_REFERENCE) tr1;
			{
				static EIF_TYPE_INDEX typarr0[] = {687,896,0xFFFF};
				EIF_TYPE typres0;
				static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
				
				typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
				tr1 = RTLNS(typres0.id, 687, _OBJSIZ_1_1_0_1_0_0_0_0_);
			}
			F688_4387(RTCW(tr1), ((EIF_INTEGER_32) 0L));
			Result = (EIF_REFERENCE) tr1;
			F457_3665(RTCW(loc1));
			for (;;) {
				tr1 = F457_3678(RTCW(loc1));
				loc4 = tr1;
				if ((EIF_BOOLEAN) !EIF_TEST(loc4)) break;
				tr1 = RTLNS(eif_new_type(729, 0x00).id, 729, _OBJSIZ_4_6_2_4_1_1_2_1_);
				tr2 = RTLNS(eif_new_type(761, 0x00).id, 761, _OBJSIZ_2_1_0_0_0_0_0_0_);
				F762_5282(RTCW(tr2), arg1);
				tr2 = F762_5309(RTCW(tr2), loc4);
				F729_4716(RTCW(tr1), tr2);
				loc3 = (EIF_REFERENCE) tr1;
				tb1 = '\0';
				tb2 = '\0';
				tb3 = F729_4746(RTCW(loc3));
				if (tb3) {
					tb3 = F729_4749(RTCW(loc3));
					tb2 = tb3;
				}
				if (tb2) {
					tb2 = F729_4753(RTCW(loc3));
					tb1 = tb2;
				}
				if (tb1) {
					(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R1930[Dtype(Result)-282])(RTCW(Result), loc4);
				}
				F457_3665(RTCW(loc1));
			}
			F457_3669(RTCW(loc1));
		}
	} else {
		tb1 = '\0';
		if ((EIF_BOOLEAN)(loc1 != NULL)) {
			tb2 = F457_3681(RTCW(loc1));
			tb1 = (EIF_BOOLEAN) !tb2;
		}
		if (tb1) {
			F457_3669(RTCW(loc1));
		}
	}
	RTE_E
	RTXSC;
	loc2 = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
	RTER;
	/* NOTREACHED */
	RTE_EE
	RTEOK;
	RTLE;
	return Result;
}
#undef EIF_VOLATILE
#define EIF_VOLATILE

/* {FILE_UTILITIES}.directory_names */
#undef EIF_VOLATILE
#define EIF_VOLATILE volatile
EIF_REFERENCE F56_746 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	RTED;
	EIF_REFERENCE EIF_VOLATILE loc1 = (EIF_REFERENCE) 0;
	EIF_BOOLEAN EIF_VOLATILE loc2 = (EIF_BOOLEAN) 0;
	EIF_REFERENCE EIF_VOLATILE loc3 = (EIF_REFERENCE) 0;
	EIF_REFERENCE EIF_VOLATILE loc4 = (EIF_REFERENCE) 0;
	EIF_REFERENCE EIF_VOLATILE saved_except = (EIF_REFERENCE) 0;
	EIF_REFERENCE  EIF_VOLATILE tr1 = NULL;
	EIF_REFERENCE  EIF_VOLATILE tr2 = NULL;
	EIF_INTEGER_32  EIF_VOLATILE ti4_1;
	EIF_CHARACTER_32  EIF_VOLATILE tw1;
	EIF_CHARACTER_32  EIF_VOLATILE tw2;
	EIF_BOOLEAN  EIF_VOLATILE tb1;
	EIF_BOOLEAN  EIF_VOLATILE tb2;
	EIF_BOOLEAN  EIF_VOLATILE tb3;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	RTXD;
	
	RTLI(9);
	RTLR(0,loc1);
	RTLR(1,tr1);
	RTLR(2,arg1);
	RTLR(3,Current);
	RTLR(4,Result);
	RTLR(5,loc4);
	RTLR(6,loc3);
	RTLR(7,tr2);
	RTLR(8,saved_except);
	RTLIU(9);
	RTXSLS;
	
	RTEV;
	RTGC;
	RTE_T
	if ((EIF_BOOLEAN) !loc2) {
		tr1 = RTLNS(eif_new_type(456, 0x00).id, 456, _OBJSIZ_3_0_0_1_0_2_0_0_);
		F457_3658(RTCW(tr1), arg1);
		loc1 = (EIF_REFERENCE) tr1;
		tb1 = '\0';
		tb2 = F457_3683(RTCW(loc1));
		if (tb2) {
			tb2 = F457_3684(RTCW(loc1));
			tb1 = tb2;
		}
		if (tb1) {
			F457_3668(RTCW(loc1));
			{
				static EIF_TYPE_INDEX typarr0[] = {687,896,0xFFFF};
				EIF_TYPE typres0;
				static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
				
				typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
				tr1 = RTLNS(typres0.id, 687, _OBJSIZ_1_1_0_1_0_0_0_0_);
			}
			F688_4387(RTCW(tr1), ((EIF_INTEGER_32) 0L));
			Result = (EIF_REFERENCE) tr1;
			F457_3665(RTCW(loc1));
			for (;;) {
				tr1 = F457_3678(RTCW(loc1));
				loc4 = tr1;
				if ((EIF_BOOLEAN) !EIF_TEST(loc4)) break;
				tb1 = '\01';
				tb2 = '\0';
				ti4_1 = *(EIF_INTEGER_32 *)(loc4+ _LNGOFF_1_1_0_2_);
				if ((EIF_BOOLEAN)(ti4_1 == ((EIF_INTEGER_32) 1L))) {
					tw1 = F897_6945(loc4, ((EIF_INTEGER_32) 1L));
					tw2 = (EIF_CHARACTER_32) (EIF_CHARACTER_8) '.';
					tb2 = (EIF_BOOLEAN)(tw1 == tw2);
				}
				if (!(tb2)) {
					tb2 = '\0';
					tb3 = '\0';
					ti4_1 = *(EIF_INTEGER_32 *)(loc4+ _LNGOFF_1_1_0_2_);
					if ((EIF_BOOLEAN)(ti4_1 == ((EIF_INTEGER_32) 2L))) {
						tw1 = F897_6945(loc4, ((EIF_INTEGER_32) 1L));
						tw2 = (EIF_CHARACTER_32) (EIF_CHARACTER_8) '.';
						tb3 = (EIF_BOOLEAN)(tw1 == tw2);
					}
					if (tb3) {
						tw1 = F897_6945(loc4, ((EIF_INTEGER_32) 2L));
						tw2 = (EIF_CHARACTER_32) (EIF_CHARACTER_8) '.';
						tb2 = (EIF_BOOLEAN)(tw1 == tw2);
					}
					tb1 = tb2;
				}
				if (tb1) {
				} else {
					tr1 = RTLNS(eif_new_type(456, 0x00).id, 456, _OBJSIZ_3_0_0_1_0_2_0_0_);
					tr2 = RTLNS(eif_new_type(761, 0x00).id, 761, _OBJSIZ_2_1_0_0_0_0_0_0_);
					F762_5282(RTCW(tr2), arg1);
					tr2 = F762_5309(RTCW(tr2), loc4);
					F457_3660(RTCW(tr1), tr2);
					loc3 = (EIF_REFERENCE) tr1;
					tb1 = '\0';
					tb2 = F457_3683(RTCW(loc3));
					if (tb2) {
						tb2 = F457_3684(RTCW(loc3));
						tb1 = tb2;
					}
					if (tb1) {
						(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R1930[Dtype(Result)-282])(RTCW(Result), loc4);
					}
				}
				F457_3665(RTCW(loc1));
			}
			F457_3669(RTCW(loc1));
		}
	} else {
		tb1 = '\0';
		if ((EIF_BOOLEAN)(loc1 != NULL)) {
			tb2 = F457_3681(RTCW(loc1));
			tb1 = (EIF_BOOLEAN) !tb2;
		}
		if (tb1) {
			F457_3669(RTCW(loc1));
		}
	}
	RTE_E
	RTXSC;
	loc2 = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
	RTER;
	/* NOTREACHED */
	RTE_EE
	RTEOK;
	RTLE;
	return Result;
}
#undef EIF_VOLATILE
#define EIF_VOLATILE

/* {FILE_UTILITIES}.file_exists */
#undef EIF_VOLATILE
#define EIF_VOLATILE volatile
EIF_BOOLEAN F56_753 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	RTED;
	EIF_REFERENCE EIF_VOLATILE loc1 = (EIF_REFERENCE) 0;
	EIF_BOOLEAN EIF_VOLATILE loc2 = (EIF_BOOLEAN) 0;
	EIF_REFERENCE EIF_VOLATILE saved_except = (EIF_REFERENCE) 0;
	EIF_REFERENCE  EIF_VOLATILE tr1 = NULL;
	EIF_BOOLEAN  EIF_VOLATILE tb1;
	EIF_BOOLEAN  EIF_VOLATILE tb2;
	EIF_VOLATILE EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	RTXD;
	
	RTLI(4);
	RTLR(0,arg1);
	RTLR(1,loc1);
	RTLR(2,tr1);
	RTLR(3,saved_except);
	RTLIU(4);
	RTXSLS;
	
	RTEV;
	RTGC;
	RTE_T
	tb1 = '\0';
	tb2 = (FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE)) R4839[Dtype(arg1)-890])(RTCW(arg1));
	if ((EIF_BOOLEAN) !tb2) {
		tb1 = (EIF_BOOLEAN) !loc2;
	}
	if (tb1) {
		tr1 = RTLNS(eif_new_type(729, 0x00).id, 729, _OBJSIZ_4_6_2_4_1_1_2_1_);
		F729_4715(RTCW(tr1), arg1);
		loc1 = (EIF_REFERENCE) tr1;
		Result = '\0';
		tb1 = F729_4746(RTCW(loc1));
		if (tb1) {
			tb1 = F729_4753(RTCW(loc1));
			Result = tb1;
		}
	}
	RTE_E
	RTXSC;
	loc2 = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
	RTER;
	/* NOTREACHED */
	RTE_EE
	RTEOK;
	RTLE;
	return Result;
}
#undef EIF_VOLATILE
#define EIF_VOLATILE

void EIF_Minit35 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-18.01.10.1424.tar: F_code/C1/fi35.c <==
/*
 * Code for class reference FILE_UTILITIES
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "fi35.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {FILE_UTILITIES}.directory_exists */
EIF_BOOLEAN F54_703 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,arg1);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	Result = '\0';
	tb1 = (FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE)) R5019[Dtype(arg1)-942])(RTCW(arg1));
	if ((EIF_BOOLEAN) !tb1) {
		tr1 = RTLNS(eif_new_type(457, 0x01).id, 457, _OBJSIZ_3_0_0_1_0_2_0_0_);
		F458_3774(RTCW(tr1), arg1);
		tb1 = F458_3799(RTCW(tr1));
		Result = tb1;
	}
	RTLE;
	return Result;
}

/* {FILE_UTILITIES}.file_names */
#undef EIF_VOLATILE
#define EIF_VOLATILE volatile
EIF_REFERENCE F54_704 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	RTED;
	EIF_REFERENCE EIF_VOLATILE loc1 = (EIF_REFERENCE) 0;
	EIF_BOOLEAN EIF_VOLATILE loc2 = (EIF_BOOLEAN) 0;
	EIF_REFERENCE EIF_VOLATILE loc3 = (EIF_REFERENCE) 0;
	EIF_REFERENCE EIF_VOLATILE loc4 = (EIF_REFERENCE) 0;
	EIF_REFERENCE EIF_VOLATILE saved_except = (EIF_REFERENCE) 0;
	EIF_REFERENCE  EIF_VOLATILE tr1 = NULL;
	EIF_REFERENCE  EIF_VOLATILE tr2 = NULL;
	EIF_BOOLEAN  EIF_VOLATILE tb1;
	EIF_BOOLEAN  EIF_VOLATILE tb2;
	EIF_BOOLEAN  EIF_VOLATILE tb3;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	RTXD;
	
	RTLI(9);
	RTLR(0,loc1);
	RTLR(1,tr1);
	RTLR(2,arg1);
	RTLR(3,Current);
	RTLR(4,Result);
	RTLR(5,loc4);
	RTLR(6,loc3);
	RTLR(7,tr2);
	RTLR(8,saved_except);
	RTLIU(9);
	RTXSLS;
	
	RTEV;
	RTGC;
	RTE_T
	if ((EIF_BOOLEAN) !loc2) {
		tr1 = RTLNS(eif_new_type(457, 0x01).id, 457, _OBJSIZ_3_0_0_1_0_2_0_0_);
		F458_3774(RTCW(tr1), arg1);
		loc1 = (EIF_REFERENCE) tr1;
		tb1 = '\0';
		tb2 = F458_3799(RTCW(loc1));
		if (tb2) {
			tb2 = F458_3800(RTCW(loc1));
			tb1 = tb2;
		}
		if (tb1) {
			F458_3784(RTCW(loc1));
			{
				static EIF_TYPE_INDEX typarr0[] = {0xFF01,750,0xFF01,947,0xFFFF};
				EIF_TYPE typres0;
				static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
				
				typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
				tr1 = RTLNS(typres0.id, 750, _OBJSIZ_1_1_0_1_0_0_0_0_);
			}
			F751_4684(RTCW(tr1), ((EIF_INTEGER_32) 0L));
			Result = (EIF_REFERENCE) tr1;
			F458_3781(RTCW(loc1));
			for (;;) {
				tr1 = F458_3794(RTCW(loc1));
				loc4 = tr1;
				if ((EIF_BOOLEAN) !EIF_TEST(loc4)) break;
				tr1 = RTLNS(eif_new_type(778, 0x01).id, 778, _OBJSIZ_4_6_2_4_1_1_2_1_);
				tr2 = RTLNS(eif_new_type(812, 0x01).id, 812, _OBJSIZ_2_1_0_0_0_0_0_0_);
				F813_5552(RTCW(tr2), arg1);
				tr2 = F813_5579(RTCW(tr2), loc4);
				F777_4950(RTCW(tr1), tr2);
				loc3 = (EIF_REFERENCE) tr1;
				tb1 = '\0';
				tb2 = '\0';
				tb3 = F777_4980(RTCW(loc3));
				if (tb3) {
					tb3 = F777_4983(RTCW(loc3));
					tb2 = tb3;
				}
				if (tb2) {
					tb2 = F777_4987(RTCW(loc3));
					tb1 = tb2;
				}
				if (tb1) {
					(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R1966[Dtype(Result)-282])(RTCW(Result), loc4);
				}
				F458_3781(RTCW(loc1));
			}
			F458_3785(RTCW(loc1));
		}
	} else {
		tb1 = '\0';
		if ((EIF_BOOLEAN)(loc1 != NULL)) {
			tb2 = F458_3797(RTCW(loc1));
			tb1 = (EIF_BOOLEAN) !tb2;
		}
		if (tb1) {
			F458_3785(RTCW(loc1));
		}
	}
	RTE_E
	RTXSC;
	loc2 = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
	RTER;
	/* NOTREACHED */
	RTE_EE
	RTEOK;
	RTLE;
	return Result;
}
#undef EIF_VOLATILE
#define EIF_VOLATILE

/* {FILE_UTILITIES}.directory_names */
#undef EIF_VOLATILE
#define EIF_VOLATILE volatile
EIF_REFERENCE F54_705 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	RTED;
	EIF_REFERENCE EIF_VOLATILE loc1 = (EIF_REFERENCE) 0;
	EIF_BOOLEAN EIF_VOLATILE loc2 = (EIF_BOOLEAN) 0;
	EIF_REFERENCE EIF_VOLATILE loc3 = (EIF_REFERENCE) 0;
	EIF_REFERENCE EIF_VOLATILE loc4 = (EIF_REFERENCE) 0;
	EIF_REFERENCE EIF_VOLATILE saved_except = (EIF_REFERENCE) 0;
	EIF_REFERENCE  EIF_VOLATILE tr1 = NULL;
	EIF_REFERENCE  EIF_VOLATILE tr2 = NULL;
	EIF_INTEGER_32  EIF_VOLATILE ti4_1;
	EIF_CHARACTER_32  EIF_VOLATILE tw1;
	EIF_CHARACTER_32  EIF_VOLATILE tw2;
	EIF_BOOLEAN  EIF_VOLATILE tb1;
	EIF_BOOLEAN  EIF_VOLATILE tb2;
	EIF_BOOLEAN  EIF_VOLATILE tb3;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	RTXD;
	
	RTLI(9);
	RTLR(0,loc1);
	RTLR(1,tr1);
	RTLR(2,arg1);
	RTLR(3,Current);
	RTLR(4,Result);
	RTLR(5,loc4);
	RTLR(6,loc3);
	RTLR(7,tr2);
	RTLR(8,saved_except);
	RTLIU(9);
	RTXSLS;
	
	RTEV;
	RTGC;
	RTE_T
	if ((EIF_BOOLEAN) !loc2) {
		tr1 = RTLNS(eif_new_type(457, 0x01).id, 457, _OBJSIZ_3_0_0_1_0_2_0_0_);
		F458_3774(RTCW(tr1), arg1);
		loc1 = (EIF_REFERENCE) tr1;
		tb1 = '\0';
		tb2 = F458_3799(RTCW(loc1));
		if (tb2) {
			tb2 = F458_3800(RTCW(loc1));
			tb1 = tb2;
		}
		if (tb1) {
			F458_3784(RTCW(loc1));
			{
				static EIF_TYPE_INDEX typarr0[] = {0xFF01,750,0xFF01,947,0xFFFF};
				EIF_TYPE typres0;
				static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
				
				typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
				tr1 = RTLNS(typres0.id, 750, _OBJSIZ_1_1_0_1_0_0_0_0_);
			}
			F751_4684(RTCW(tr1), ((EIF_INTEGER_32) 0L));
			Result = (EIF_REFERENCE) tr1;
			F458_3781(RTCW(loc1));
			for (;;) {
				tr1 = F458_3794(RTCW(loc1));
				loc4 = tr1;
				if ((EIF_BOOLEAN) !EIF_TEST(loc4)) break;
				tb1 = '\01';
				tb2 = '\0';
				ti4_1 = *(EIF_INTEGER_32 *)(loc4+ _LNGOFF_1_1_0_2_);
				if ((EIF_BOOLEAN)(ti4_1 == ((EIF_INTEGER_32) 1L))) {
					tw1 = F948_7193(loc4, ((EIF_INTEGER_32) 1L));
					tw2 = (EIF_CHARACTER_32) (EIF_CHARACTER_8) '.';
					tb2 = (EIF_BOOLEAN)(tw1 == tw2);
				}
				if (!(tb2)) {
					tb2 = '\0';
					tb3 = '\0';
					ti4_1 = *(EIF_INTEGER_32 *)(loc4+ _LNGOFF_1_1_0_2_);
					if ((EIF_BOOLEAN)(ti4_1 == ((EIF_INTEGER_32) 2L))) {
						tw1 = F948_7193(loc4, ((EIF_INTEGER_32) 1L));
						tw2 = (EIF_CHARACTER_32) (EIF_CHARACTER_8) '.';
						tb3 = (EIF_BOOLEAN)(tw1 == tw2);
					}
					if (tb3) {
						tw1 = F948_7193(loc4, ((EIF_INTEGER_32) 2L));
						tw2 = (EIF_CHARACTER_32) (EIF_CHARACTER_8) '.';
						tb2 = (EIF_BOOLEAN)(tw1 == tw2);
					}
					tb1 = tb2;
				}
				if (tb1) {
				} else {
					tr1 = RTLNS(eif_new_type(457, 0x01).id, 457, _OBJSIZ_3_0_0_1_0_2_0_0_);
					tr2 = RTLNS(eif_new_type(812, 0x01).id, 812, _OBJSIZ_2_1_0_0_0_0_0_0_);
					F813_5552(RTCW(tr2), arg1);
					tr2 = F813_5579(RTCW(tr2), loc4);
					F458_3776(RTCW(tr1), tr2);
					loc3 = (EIF_REFERENCE) tr1;
					tb1 = '\0';
					tb2 = F458_3799(RTCW(loc3));
					if (tb2) {
						tb2 = F458_3800(RTCW(loc3));
						tb1 = tb2;
					}
					if (tb1) {
						(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R1966[Dtype(Result)-282])(RTCW(Result), loc4);
					}
				}
				F458_3781(RTCW(loc1));
			}
			F458_3785(RTCW(loc1));
		}
	} else {
		tb1 = '\0';
		if ((EIF_BOOLEAN)(loc1 != NULL)) {
			tb2 = F458_3797(RTCW(loc1));
			tb1 = (EIF_BOOLEAN) !tb2;
		}
		if (tb1) {
			F458_3785(RTCW(loc1));
		}
	}
	RTE_E
	RTXSC;
	loc2 = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
	RTER;
	/* NOTREACHED */
	RTE_EE
	RTEOK;
	RTLE;
	return Result;
}
#undef EIF_VOLATILE
#define EIF_VOLATILE

/* {FILE_UTILITIES}.file_exists */
#undef EIF_VOLATILE
#define EIF_VOLATILE volatile
EIF_BOOLEAN F54_712 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	RTED;
	EIF_REFERENCE EIF_VOLATILE loc1 = (EIF_REFERENCE) 0;
	EIF_BOOLEAN EIF_VOLATILE loc2 = (EIF_BOOLEAN) 0;
	EIF_REFERENCE EIF_VOLATILE saved_except = (EIF_REFERENCE) 0;
	EIF_REFERENCE  EIF_VOLATILE tr1 = NULL;
	EIF_BOOLEAN  EIF_VOLATILE tb1;
	EIF_BOOLEAN  EIF_VOLATILE tb2;
	EIF_VOLATILE EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	RTXD;
	
	RTLI(4);
	RTLR(0,arg1);
	RTLR(1,loc1);
	RTLR(2,tr1);
	RTLR(3,saved_except);
	RTLIU(4);
	RTXSLS;
	
	RTEV;
	RTGC;
	RTE_T
	tb1 = '\0';
	tb2 = (FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE)) R5019[Dtype(arg1)-942])(RTCW(arg1));
	if ((EIF_BOOLEAN) !tb2) {
		tb1 = (EIF_BOOLEAN) !loc2;
	}
	if (tb1) {
		tr1 = RTLNS(eif_new_type(778, 0x01).id, 778, _OBJSIZ_4_6_2_4_1_1_2_1_);
		F777_4949(RTCW(tr1), arg1);
		loc1 = (EIF_REFERENCE) tr1;
		Result = '\0';
		tb1 = F777_4980(RTCW(loc1));
		if (tb1) {
			tb1 = F777_4987(RTCW(loc1));
			Result = tb1;
		}
	}
	RTE_E
	RTXSC;
	loc2 = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
	RTER;
	/* NOTREACHED */
	RTE_EE
	RTEOK;
	RTLE;
	return Result;
}
#undef EIF_VOLATILE
#define EIF_VOLATILE

void EIF_Minit35 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
